@@ -23,15 +23,14 @@ class bcolors:
     UNDERLINE = '\033[4m'
 
 class AgentLifeCycle:
+
+    # default configuration of containers and images
     _docker_container_names = ["cgs_agent","cgs_diagnostics_agent","remote_intervention_agent","ecs_server","cgs_diagnostics_ecs_api","cgs_diagnostics_streamer_api","rosbridge"]
     _docker_images = {}
     _docker_images["remote_intervention_agent"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/remote_intervention_agent:latest"
-    _docker_images["cgs_agent"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_rosbridge_listener_agent:latest"
     _docker_images["cgs_diagnostics_agent"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_diagnostics_agent:latest"
-    _docker_images["ecs_server"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_rosbridge_listener_agent:latest"
     _docker_images["cgs_diagnostics_ecs_api"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_diagnostics_api:latest"
     _docker_images["cgs_diagnostics_streamer_api"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/cognicept_diagnostics_api:latest"
-    _docker_images["rosbridge"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/orbitty:latest"
     _docker_images["orbitty"] = "412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/orbitty:latest"
     
     def configure_containers(object, cfg):
@@ -47,6 +46,10 @@ class AgentLifeCycle:
                     i = i + 1
             else:
                 print("`COG_AGENT_CONTAINERS` and `COG_AGENT_IMAGES` do not coincide. Using default.")
+
+            if("COG_ORBITTY_ENABLED" in cfg.config and "COG_ORBITTY_IMAGE" in cfg.config):
+                if(bool(cfg.config["COG_ORBITTY_ENABLED"])):
+                    object._docker_images["orbitty"] = cfg.config["COG_ORBITTY_IMAGE"]
         else:
             print("Undefined `COG_AGENT_CONTAINERS` or `COG_AGENT_IMAGES`. Using default.")
 
@@ -249,7 +252,8 @@ class AgentLifeCycle:
         except docker.errors.APIError:
             print("You don't have ECR repository permissions. Check you AWS credentials with Cognicept team.")
 
-        for container_name, image_name in object._docker_images.items():
+        images = set(object._docker_images.values())
+        for image_name in images:
             print(image_name)
             result = docker_client.images.pull(image_name)
 
