@@ -6,7 +6,6 @@ import argparse
 import os
 import sys
 import pkg_resources
-sys.path.append("/home/jakub/code/cognicept-shell")
 
 from cogniceptshell.configuration import Configuration
 from cogniceptshell.agent_life_cycle import AgentLifeCycle
@@ -24,6 +23,7 @@ def main():
 
     parser_config = subparsers.add_parser('config', help='Configure Cognicept tools')
     parser_status = subparsers.add_parser('status', help='Get status of Cognicept agents')
+    parser_lastevent = subparsers.add_parser('lastevent', help='Display last event log reported by Cognicept agent')
     parser_update = subparsers.add_parser('update', help='Update Cognicept tools')
     parser_restart = subparsers.add_parser('restart', help='Restart Cognicept agents')
     parser_stop = subparsers.add_parser('stop', help='Stops Cognicept agents')
@@ -40,6 +40,9 @@ def main():
     parser_status.set_defaults(func=agent_lifetime.get_status)
     parser_status.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
 
+    parser_lastevent.set_defaults(func=agent_lifetime.get_last_event)
+    parser_lastevent.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
+
     parser_restart.set_defaults(func=agent_lifetime.restart)
     parser_restart.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
 
@@ -52,12 +55,18 @@ def main():
     parser_orbitty.set_defaults(func=agent_lifetime.run_orbitty)
     parser_orbitty.add_argument('--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
 
-    # Add the arguments
+    # Parse the arguments
     args = parser.parse_args()
-    args.config = local_cfg
-    
-    if(hasattr(args,'func')):
-        args.func(args)
+
+    if("path" not in args):
+        parser.print_help()
+    else:
+        local_cfg.load_config(args.path)
+        agent_lifetime.configure_containers(local_cfg)
+        args.config = local_cfg
+        
+        if(hasattr(args,'func')):
+            args.func(args)
 
 
 
